# c2qa-qiskit

NQI C2QA project to simulate hybrid qubits within QisKit.

## Install

Use a Python virtual environment to install compatible version of QisKit.

```bash
git clone https://github.com/C2QA/c2qa-qiskit.git
cd c2qa-qiskit
./install-dependencies.sh
```

## Activate Virtual Environment

Before using c2qa-qiskit, first install the depencies (as above) and then activate the Python virtual environment.

```bash
cd <path/to/c2qa-qiskit>
source venv/bin/activate
```

## Run the code

After activating the Python virtual environment, develop and run your Python scripts as normal.

### Tutorials

Jupyter Notebook tutorials can be found in the `tutorials` folder. JupyterLab is a dependency found in `requirements.txt`, so after installing and activating the virtual environment, to run the tutorials simply start Jupyter with `jupyter lab` and then navigate to the desired tutorial.

